Returns an overview of 59 NLS test problems originating primarily from the NIST Statistical Reference Datasets (StRD) archive; Bates and Watts (1988); and More, Garbow and Hillstrom (1981).
nls_test_list(fields = c("name", "class", "p", "n", "check"))a data.frame with high-level information about the available test problems. The following columns are returned by default:
"name" Name of the test problem for use in nls_test_problem.
"class" Either "formula" if the model is defined as a formula or "function" if defined as a function.
"p" Default number of parameters in the test problem.
"n" Default number of residuals in the test problem.
"check" One of the following three options: (1) "p, n fixed" if the listed values for p and n are the only ones possible;
(2) "p <= n free" if the values for p and n are not fixed, but p must be smaller or equal to n;
(3) "p == n free" if the values for p and n are not fixed, but p must be equal to n.
optional character vector to return a subset of columns in the data.frame.
D.M. Bates and Watts, D.G. (1988). Nonlinear Regression Analysis and Its Applications, Wiley, ISBN: 0471816434.
J.J. Moré, Garbow, B.S. and Hillstrom, K.E. (1981). Testing unconstrained optimization software, ACM Transactions on Mathematical Software, 7(1), 17-41.
## available test problems
nls_test_list()
Run the code above in your browser using DataLab